@@ -248,7 +248,7 @@ raise ValueError('Test exception in subprocess')
 
     # Use subprocess to run the script
     process = subprocess.run(  # noqa: S603
-        ['python3.9', str(test_script)],  # noqa: S607
+        ['python', str(test_script)],  # noqa: S607
         capture_output=True,
         text=True,
         check=False,
