@@ -70,6 +70,7 @@ from pelicun.base import (
     update,
     update_vals,
 )
+from pelicun.file_io import substitute_default_path
 from pelicun.pelicun_warnings import PelicunInvalidConfigError
 
 colorama.init()
@@ -316,6 +317,7 @@ def run_pelicun(  # noqa: C901
         demand_file,
         realizations,
         output_format,
+        custom_model_dir,
         coupled_edp=coupled_edp,
         detailed_results=detailed_results,
     )
@@ -571,13 +573,14 @@ def _summary_save(
         out_files.append('DL_summary_stats.csv')
 
 
-def _parse_config_file(  # noqa: C901
+def _parse_config_file(  # noqa: C901, PLR0912
     config_path: Path,
     output_path: Path,
     auto_script_path: Path | None,
     demand_file: str,
     realizations: int,
     output_format: list | None,
+    custom_model_dir: str | None,
     *,
     coupled_edp: bool,
     detailed_results: bool,
@@ -591,18 +594,21 @@ def _parse_config_file(  # noqa: C901
         Path to the configuration file.
     output_path : Path
         Directory for output files.
-    auto_script_path : str
+    auto_script_path : Path
         Path to the auto-generation script.
     demand_file : str
         Path to the demand data file.
     realizations : int
         Number of realizations.
+    output_format : str
+        Output format (CSV, JSON).
+    custom_model_dir: str, optional
+        String pointing to a directory with files that define user-provided model
+        parameters for a customized damage and loss assessment.
     coupled_EDP : bool
         Whether to consider coupled EDPs.
     detailed_results : bool
         Whether to generate detailed results.
-    output_format : str
-        Output format (CSV, JSON).
 
     Returns
     -------
@@ -638,20 +644,91 @@ def _parse_config_file(  # noqa: C901
         msg = 'The provided config file does not conform to the schema.'
         raise PelicunInvalidConfigError(msg) from exc
 
+    # identify the folder with the damage and loss model data
     if is_unspecified(config, 'DL'):
-        log_msg('Damage and Loss configuration missing from config file. ')
+        dl_method = get(config, 'Applications/DL/ApplicationData/DL_Method')
 
-        if auto_script_path is None:
-            msg = 'No `DL` entry in config file.'
-            raise PelicunInvalidConfigError(msg)
+        if dl_method == 'User-provided Models':
+            if custom_model_dir is not None:
+                dl_model_folder = custom_model_dir
+            else:
+                dl_model_folder = get(
+                    config, 'Applications/DL/ApplicationData/custom_model_dir'
+                )
 
-        log_msg('Trying to auto-populate')
+            assert isinstance(dl_model_folder, str)
+            dl_model_folder = Path(dl_model_folder).resolve()
+            assert dl_model_folder.exists(), f'{dl_model_folder} does not exist'
+            assert dl_model_folder.is_dir(), f'{dl_model_folder} is not a directory'
 
-        # Add the demandFile to the config dict to allow demand dependent auto-population
+            auto_script_paths = [
+                Path(dl_model_folder / 'pelicun_config.py').resolve()
+            ]
+
+        else:
+            dl_methods = [m.strip() for m in dl_method.split(',')]
+
+            auto_script_paths = []
+            for dl_method in dl_methods:
+                auto_script_path = substitute_default_path(
+                    [f'PelicunDefault/{dl_method}/pelicun_config.py']
+                )[0]
+                auto_script_paths.append(Path(auto_script_path).resolve())
+
+        for auto_script_path in auto_script_paths:
+            if not auto_script_path.exists():
+                msg = (
+                    f'No `DL` entry in config file and the following path '
+                    f'does not point to a valid pelicun configuration file: '
+                    f'{auto_script_path}.'
+                )
+                raise PelicunInvalidConfigError(msg)
+
+        # Add the demandFile to the config dict to allow demand-dependent auto-population
         update(config, '/DL/Demands/DemandFilePath', demand_file)
         update(config, '/DL/Demands/SampleSize', str(realizations))
 
-        config_ap, comp = auto_populate(config, auto_script_path)
+        for script_id, auto_script_path in enumerate(auto_script_paths):
+            log_msg(f'Configuring Pelicun using {auto_script_path}')
+
+            if script_id == 0:
+                config_ap, comp = auto_populate(config, auto_script_path, script_id)
+
+            else:
+                config_ap_i, comp_i = auto_populate(
+                    config, auto_script_path, script_id
+                )
+
+                comp = pd.concat([comp, comp_i])
+
+                # TODO(AZS): Currently, this is set up to work with the old flood rules
+                # Requires updating once the inference is moved to BRAILS and the flood
+                # config is updated.
+                # Requires further updating to make it more generic and support more than
+                # just hurricane wind & surge
+                update(
+                    config_ap,
+                    'DL/Asset/ComponentDatabase',
+                    (
+                        f"{get(config_ap, 'DL/Asset/ComponentDatabase')},"
+                        f"{get(config_ap_i, 'DL/Asset/ComponentDatabase')}"
+                    ),
+                )
+
+                update(
+                    config_ap,
+                    'DL/Losses/Repair/ConsequenceDatabase',
+                    (
+                        f"{get(config_ap, 'DL/Losses/Repair/ConsequenceDatabase')},"
+                        f"{get(config_ap_i, 'DL/Losses/Repair/ConsequenceDatabase')}"
+                    ),
+                )
+
+                update(
+                    config_ap,
+                    'DL/Losses/Repair/CombinationMethod',
+                    'Hazus Hurricane',
+                )
 
         if is_unspecified(config_ap, 'DL'):
             msg = (
@@ -729,6 +806,14 @@ def _parse_config_file(  # noqa: C901
         if is_unspecified(config_ap, 'DL/Losses'):
             update(config_ap, 'DL/Outputs/Loss', {})
 
+        if is_specified(config, 'outputs'):
+            if (not config['outputs']['IM']) and (not config['outputs']['EDP']):
+                update(config_ap, 'DL/Outputs/Demand', {})
+            if not config['outputs']['DM']:
+                update(config_ap, 'DL/Outputs/Damage', {})
+            if not config['outputs']['DV']:
+                update(config_ap, 'DL/Outputs/Loss', {})
+
         # save the extended config to a file
         config_ap_path = Path(config_path.stem + '_ap.json').resolve()
 
@@ -958,20 +1043,27 @@ def _create_json_files_if_requested(
                 pd.read_csv(output_path / filename, index_col=0), axis=1
             )
 
-        if 'Units' in data.index:
+        # Check for units information (case-insensitive)
+        units_key = None
+        for key in data.index:
+            if str(key).lower() == 'units':
+                units_key = key
+                break
+
+        if units_key is not None:
             df_units = convert_to_SimpleIndex(
-                data.loc['Units', :].to_frame().T,  # type: ignore
+                data.loc[units_key, :].to_frame().T,  # type: ignore
                 axis=1,
             )
 
-            data = data.drop('Units', axis=0)
+            data = data.drop(units_key, axis=0)
 
             out_dict = convert_df_to_dict(data)
 
             out_dict.update(
                 {
                     'Units': {
-                        col: df_units.loc['Units', col] for col in df_units.columns
+                        col: df_units.loc[units_key, col] for col in df_units.columns
                     }
                 }
             )
@@ -1003,23 +1095,29 @@ def _result_summary(
 
     """
     damage_sample = assessment.damage.save_sample()
-    if damage_sample is None or agg_repair is None:
+    if damage_sample is None and agg_repair is None:
         return pd.DataFrame(), pd.DataFrame()
 
-    assert isinstance(damage_sample, pd.DataFrame)
-    damage_sample = damage_sample.groupby(level=['cmp', 'ds'], axis=1).sum()  # type: ignore
-    assert isinstance(damage_sample, pd.DataFrame)
-    damage_sample_s = convert_to_SimpleIndex(damage_sample, axis=1)
+    if damage_sample is not None:
+        assert isinstance(damage_sample, pd.DataFrame)
+        damage_sample = damage_sample.groupby(level=['cmp', 'ds'], axis=1).sum()  # type: ignore
+        assert isinstance(damage_sample, pd.DataFrame)
+        damage_sample_s = convert_to_SimpleIndex(damage_sample, axis=1)
 
-    if 'collapse-1' in damage_sample_s.columns:
-        damage_sample_s['collapse'] = damage_sample_s['collapse-1']
-    else:
-        damage_sample_s['collapse'] = np.zeros(damage_sample_s.shape[0])
+        if 'collapse-1' in damage_sample_s.columns:
+            damage_sample_s['collapse'] = damage_sample_s['collapse-1']
+        else:
+            damage_sample_s['collapse'] = np.zeros(damage_sample_s.shape[0])
+
+        if 'irreparable-1' in damage_sample_s.columns:
+            damage_sample_s['irreparable'] = damage_sample_s['irreparable-1']
+        else:
+            damage_sample_s['irreparable'] = np.zeros(damage_sample_s.shape[0])
+
+        damage_sample_s = damage_sample_s[['collapse', 'irreparable']]
 
-    if 'irreparable-1' in damage_sample_s.columns:
-        damage_sample_s['irreparable'] = damage_sample_s['irreparable-1']
     else:
-        damage_sample_s['irreparable'] = np.zeros(damage_sample_s.shape[0])
+        damage_sample_s = pd.DataFrame()
 
     if agg_repair is not None:
         agg_repair_s = convert_to_SimpleIndex(agg_repair, axis=1)
@@ -1027,9 +1125,7 @@ def _result_summary(
     else:
         agg_repair_s = pd.DataFrame()
 
-    summary = pd.concat(
-        [agg_repair_s, damage_sample_s[['collapse', 'irreparable']]], axis=1
-    )
+    summary = pd.concat([agg_repair_s, damage_sample_s], axis=1)
 
     summary_stats = describe(summary)
 
@@ -1311,7 +1407,7 @@ def _damage_save(
             out_files.append('DMG_grp_stats.csv')
 
 
-def _loss_save(
+def _loss_save(  # noqa: C901
     output_config: dict,
     assessment: DLCalculationAssessment,
     output_path: Path,
@@ -1345,12 +1441,21 @@ def _loss_save(
     repair_units = repair_units_series.to_frame().T
 
     if aggregate_colocated:
-        repair_units = repair_units.groupby(  # type: ignore
-            level=['dv', 'loss', 'dmg', 'ds', 'loc', 'dir'], axis=1
-        ).first()
-        repair_groupby_uid = repair_sample.groupby(  # type: ignore
-            level=['dv', 'loss', 'dmg', 'ds', 'loc', 'dir'], axis=1
-        )
+        if 'ds' in repair_units.columns.names:
+            repair_units = repair_units.groupby(  # type: ignore
+                level=['dv', 'loss', 'dmg', 'ds', 'loc', 'dir'], axis=1
+            ).first()
+            repair_groupby_uid = repair_sample.groupby(  # type: ignore
+                level=['dv', 'loss', 'dmg', 'ds', 'loc', 'dir'], axis=1
+            )
+        else:
+            repair_units = repair_units.groupby(  # type: ignore
+                level=['dv', 'loss', 'dmg', 'loc', 'dir'], axis=1
+            ).first()
+            repair_groupby_uid = repair_sample.groupby(  # type: ignore
+                level=['dv', 'loss', 'dmg', 'loc', 'dir'], axis=1
+            )
+
         repair_sample = repair_groupby_uid.sum().mask(
             repair_groupby_uid.count() == 0, np.nan
         )
